==> libnjb1_1.1.orig.tar.gz: libnjb-1.1/sample/getfile.c <==
#include <sys/types.h>
#include <stdio.h>
#include <stdlib.h>
#include <limits.h>
#include <unistd.h>
#include <libnjb.h>

int progress(u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data );
void usage(void);

extern int njb_error;

int main (int argc, char **argv)
{
	njb_t njbs[NJB_MAX_DEVICES], *njb;
	int n, opt, debug;
	u_int32_t id;
	u_int64_t size;
	extern int optind;
	extern char *optarg;
	char *endptr;
	char *file;

	debug= 0;
	size= 0;
	while ( (opt= getopt(argc, argv, "D:s:")) != -1 ) {
		switch (opt) {
		case 'D':
			debug= atoi(optarg);
			break;
		case 's':
			size= strtoul(optarg, &endptr, 10);
			if ( *endptr != '\0' ) {
				fprintf(stderr, "illegal size value %s\n",
					optarg);
				return 1;
			}
			break;
		default:
			usage();
			return 1;
		}
	}
	argc-= optind;
	argv+= optind;

	if ( argc != 2 ) {
		usage();
		return 1;
	}

	id= strtoul(argv[0], &endptr, 10);
	if ( *endptr != 0 ) {
		fprintf(stderr, "illegal value %s\n", optarg);
		return 1;
	} else if ( ! id ) {
		fprintf(stderr, "bad file id %u\n", id);
		return 1;
	}

	file= argv[1];

	if ( debug ) NJB_Set_Debug(debug);

	if ( NJB_Discover(njbs, 0, &n) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}
	if ( n == 0 ) {
		fprintf(stderr, "no NJB devices found\n");
		return 0;
	} 

	njb= njbs;

	if ( NJB_Open(njb) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}

	NJB_Capture(njb);

	if ( ! size ) {
		datafile_t *df;

		printf("Locating file %u\n", id);
		NJB_Reset_Get_Datafile_Tag(njb);
		while ( (df= NJB_Get_Datafile_Tag(njb)) ) {
			if ( df->dfid == id ) {
				size= datafile_size(df);
			}
			datafile_destroy(df);
		}
		if ( njb_error != EO_EOM ) njb_error_dump(stderr);

		if ( size ) {
			printf("%Lu bytes\n", size);
		} else {
			fprintf(stderr, "File %u not found\n", id);
		}
	}

	if ( size ) {
		if ( NJB_Get_File(njb, id, (u_int32_t) size, file, progress, NULL ) == -1 ) {
			njb_error_dump(stderr);
		}
		printf("\n");
	}

	NJB_Release(njb);

	NJB_Close(njb);

	return 0;
}

int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data)
{
	int percent = (sent*100)/total;
	printf("Progress: %qu of %qu (%d%%)\r", sent, total, percent);
	fflush(stdout);
	return 0;
}

void usage (void)
{
	fprintf(stderr, "getfile [ -s size ] <fileid> <filename>\n");
}

==> libnjb_1.2.orig.tar.gz: libnjb-1.2/sample/getfile.c <==
#include <libnjb.h>
#include <getopt.h>

int progress(u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data );
void usage(void);

extern int njb_error;

int main (int argc, char **argv)
{
	njb_t njbs[NJB_MAX_DEVICES], *njb;
	int n, opt, debug;
	u_int32_t id;
	u_int64_t size;
	extern int optind;
	extern char *optarg;
	char *endptr;
	char *file;

	debug= 0;
	size= 0;
	while ( (opt= getopt(argc, argv, "D:s:")) != -1 ) {
		switch (opt) {
		case 'D':
			debug= atoi(optarg);
			break;
		case 's':
			size= strtoul(optarg, &endptr, 10);
			if ( *endptr != '\0' ) {
				fprintf(stderr, "illegal size value %s\n",
					optarg);
				return 1;
			}
			break;
		default:
			usage();
			return 1;
		}
	}
	argc-= optind;
	argv+= optind;

	if ( argc != 2 ) {
		usage();
		return 1;
	}

	id= strtoul(argv[0], &endptr, 10);
	if ( *endptr != 0 ) {
		fprintf(stderr, "illegal value %s\n", optarg);
		return 1;
	} else if ( ! id ) {
		fprintf(stderr, "bad file id %u\n", id);
		return 1;
	}

	file= argv[1];

	if ( debug ) NJB_Set_Debug(debug);

	if ( NJB_Discover(njbs, 0, &n) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}
	if ( n == 0 ) {
		fprintf(stderr, "no NJB devices found\n");
		return 0;
	} 

	njb= njbs;

	if ( NJB_Open(njb) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}

	NJB_Capture(njb);

	if ( ! size ) {
		datafile_t *df;

		printf("Locating file %u\n", id);
		NJB_Reset_Get_Datafile_Tag(njb);
		while ( (df= NJB_Get_Datafile_Tag(njb)) ) {
			if ( df->dfid == id ) {
				size= datafile_size(df);
			}
			datafile_destroy(df);
		}
		if ( njb_error != EO_EOM ) njb_error_dump(stderr);

		if ( size ) {
			printf("%Lu bytes\n", size);
		} else {
			fprintf(stderr, "File %u not found\n", id);
		}
	}

	if ( size ) {
		if ( NJB_Get_File(njb, id, (u_int32_t) size, file, progress, NULL ) == -1 ) {
			njb_error_dump(stderr);
		}
		printf("\n");
	}

	NJB_Release(njb);

	NJB_Close(njb);

	return 0;
}

int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data)
{
	int percent = (sent*100)/total;
#ifdef __WIN32__
	printf("Progress: %I64u of %I64u (%d%%)\r", sent, total, percent);
#else
	printf("Progress: %llu of %llu (%d%%)\r", sent, total, percent);
#endif
	fflush(stdout);
	return 0;
}

void usage (void)
{
	fprintf(stderr, "getfile [ -s size ] <fileid> <filename>\n");
}
